void tmva_fisher()
{
  cout << "running tmva_fisher" << endl;
  gROOT->SetStyle("Plain"); 
  gSystem->Load("libMLP"); 
  gSystem->Load("libTMVA.so");

  // Set up the output file and TMVA toolkit
  TFile f("fisher.root", "RECREATE");
  TMVA::Factory * factory = new TMVA::Factory("TMVAanalysis", &f, "");

  // Get data to use in calculating the MVA
  TFile fsignal("signal.root");
  TFile fbg("background.root");
  TTree * tsignal = (TTree*)fsignal.Get("data");
  TTree * tbg     = (TTree*)fbg.Get("data");

  cout << "have signal tree     "<< tsignal << endl;
  cout << "have background tree "<< tbg << endl;

  // Set up the input data trees to use with TMVA
  factory->SetInputTrees( tsignal, tbg);

  // now define the variables to use in the MVA
  vector<TString>* inputVars = new vector<TString>;
  inputVars->push_back("lgdr0P1n");
  inputVars->push_back("lgdr2P1n");
  inputVars->push_back("lgdr0P1c");
  inputVars->push_back("lgdr2P1c");
  factory->SetInputVariables( inputVars );

  // Apply additional cuts on the signal and background sample.
  // Assumptions on size of training and testing sample:
  //    a) equal number of signal and background events is used for training
  //    b) any numbers of signal and background events are used for testing
  //    c) an explicit syntax can violate a)
  // more Documentation with the Factory class
  TCut mycut = "";
  factory->PrepareTrainingAndTestTree( mycut, 1000, 1000 );


  // Book the MVA methods you like to investigate.
  //  - here we just select the Fisher method
  factory->BookMethod( TMVA::Types::Fisher, "Fisher" ); 

  // Train MVAs.
  factory->TrainAllMethods();


  // Test MVAs.
  factory->TestAllMethods();


  // Evaluate variables.
  factory->EvaluateAllVariables();

  // Evaluate MVAs
  factory->EvaluateAllMethods();

  // Save the output.
  f.Close();

  //
  // Now make a few plots of the fisher for comparison
  //
  TFile f("fisher.root");
  f.cd();
  TH1F * MVA_Fisher_B = (TH1F*)f.Get("MVA_Fisher_B");
  TH1F * MVA_Fisher_S = (TH1F*)f.Get("MVA_Fisher_S");
  TH1F * MVA_Fisher_effBvsS = (TH1F*)f.Get("MVA_Fisher_effBvsS");

  TCanvas can("MVA comparison", "");
  can.cd();
  MVA_Fisher_B->SetTitle("");
  MVA_Fisher_B->SetStats(0);
  MVA_Fisher_B->SetLineColor(kBlue);
  MVA_Fisher_B->SetMarkerColor(kBlue);
  MVA_Fisher_S->SetLineColor(kRed);
  MVA_Fisher_S->SetMarkerColor(kRed);
  MVA_Fisher_B->GetXaxis()->SetTitle("Fisher");
  MVA_Fisher_B->GetYaxis()->SetTitle("Number of Entries");

  MVA_Fisher_B->Draw();
  MVA_Fisher_S->Draw("same");
  can.Print("Fisher.eps");

  MVA_Fisher_effBvsS->SetTitle("");
  MVA_Fisher_effBvsS->SetStats(0);
  MVA_Fisher_effBvsS->GetXaxis()->SetTitle("#epsilon_{signal}");
  MVA_Fisher_effBvsS->GetYaxis()->SetTitle("#epsilon_{background}");
  MVA_Fisher_effBvsS->SetLineColor(kBlue);
  MVA_Fisher_effBvsS->Draw("c");
  can.Print("Fisher_eff.eps");
}
